/* Copyright (c) 2009, Canonical Ltd. All rights reserved. */

YUI({
    base: '../../yui/current/build/',
    modules: {
        'gallery-port': {
            fullpath:
            '../../../../build/yui-gallery/gallery-port/gallery-port-min.js',
            requires: ['base','node']
        },

        'lazr.treeview': {
            fullpath: '../../../../build/treeview/treeview-min.js',
            requires: ['gallery-port']
        },
    },
    filter: 'raw',
    combine: false
    }).use('lazr.testing.runner', 'gallery-port', 'lazr.treeview',
           'event', 'event-simulate', function(Y) {

var Assert = Y.Assert;  // For easy access to isTrue(), etc.

/*
 * A wrapper for the Y.Event.simulate() function.  The wrapper accepts
 * CSS selectors and Node instances instead of raw nodes.
 */
function simulate(selector, evtype) {
    var rawnode = Y.Node.getDOMNode(Y.get(selector));
    Y.Event.simulate(rawnode, evtype);
}

var suite = new Y.Test.Suite("TreeView Tests");

suite.add(new Y.Test.Case({

    name: 'treeview_basics',

    setUp: function() {
        this.YAHOO = Y.Port();

        this.workspace = Y.get('#workspace');
        if (!this.workspace){
            Y.get(document.body).appendChild(Y.Node.create(
                '<div id="workspace" ' +
                'style="border: 1px solid blue; ' +
                'width: 20em; ' +
                'margin: 1em; ' +
                'padding: 1em">'+
                '<div id="theTree"></div>' +
                '</div>'));
            this.workspace = Y.get('#workspace');
        }
    },

    tearDown: function() {
        this.workspace.set('innerHTML', '<div id="theTree"></div>');
    },

    test_dynamic_creation: function() {
        var theTree = new this.YAHOO.widget.TreeView('theTree');
        var root = theTree.getRoot();
        var one = new this.YAHOO.widget.TextNode('label', root);
        var two = new this.YAHOO.widget.TextNode('second', root);
        Assert.areEqual(2, theTree.getNodeCount());
    },

    test_dynamic_creation_html: function() {
        var theTree = new this.YAHOO.widget.TreeView('theTree');
        var root = theTree.getRoot();
        var two = new this.YAHOO.widget.HTMLNode('<i>second</i>', root,
                                                 false, true);
        Assert.areEqual(1, theTree.getNodeCount());
    },

    test_markup_creation: function() {
        Y.get('#theTree').set('innerHTML',
                              '<ul><li>One</li><li>Two</li></ul>');
        theTree = new this.YAHOO.widget.TreeView('theTree');
        Assert.areEqual(2, theTree.getNodeCount());
    },

    test_markup_creation_html: function() {
        Y.get('#theTree').set('innerHTML',
                              '<ul><li>One</li>' +
                              '    <li><b>Two (html)</b></li>' +
                              '</ul>');
        theTree = new this.YAHOO.widget.TreeView('theTree');
        Assert.areEqual(2, theTree.getNodeCount());
    },

    test_expand: function() {
        Y.get('#theTree').set('innerHTML',
                              '<ul><li>One' +
                              '    <ul><li>One a</li>' +
                              '        <li>One b</li>' +
                              '    </ul></li>' +
                              '    <li>Two</li>' +
                              '</ul>');
        theTree = new this.YAHOO.widget.TreeView('theTree');
        theTree.render();
        var cross = Y.get('.ygtvspacer');
        simulate(cross, 'click');
        var display = Y.all('.ygtvchildren').item(1).getStyle('display');
        Assert.areEqual('block', display);
        simulate(cross, 'click');
        display = Y.all('.ygtvchildren').item(1).getStyle('display');
        Assert.areEqual('none', display);
    },

    test_destroy: function() {
        Y.get('#theTree').set('innerHTML', '<ul><li>One</li></ul>');
        theTree = new this.YAHOO.widget.TreeView('theTree');
        theTree.render();
        Assert.areEqual(1, theTree.getNodeCount());
        // Call destroy explicitly to see that it doesn't explode
        // -- usually this isn't needed.
        Y.get('#theTree').set('innerHTML', '');
        theTree.destroy();
        theTree = null;
    }

}));

Y.lazr.testing.Runner.add(suite);
Y.lazr.testing.Runner.run();
});
